require 'active_support/inflector'

module MyVR
  class Client
    include MyVR::API::Amenities
    include MyVR::API::Fees
    include MyVR::API::Photos
    include MyVR::API::Properties
    include MyVR::API::Rates
    include MyVR::API::Rooms

    attr_accessor :access_key, :last_response

    def initialize(options = {})
      @last_response = nil
      options.each do |key, value|
        instance_variable_set("@#{ key }", value)
      end
      yield(self) if block_given?
    end

    def user_agent
      @user_agent ||= "MyVRRubyGem/#{ MyVR::Version }"
    end

    def get_objects(path, params={})
      response = request(:get, path, params.dup)
      response['results']
    end

    def get_object(path, params={})
      request(:get, path, params.dup)
    end

    def request(http_method, path, params={})
      url = base_url(path, params.dup)
      c = Curl::Easy.new(url)
      c.http_auth_types = :basic
      c.username = access_key
      c.send(http_method)
      if ENV["MYVR_TEST"]
        p JSON.parse(c.body_str)
      else
        JSON.parse(c.body_str)
      end
    end

    def base_url(path, params={})
      if ENV["MYVR_TEST"]
        Addressable::URI.new(
          host: 'api.local.myvr.com',
          port: 8000,
          scheme: 'http',
          path: path,
          query_values: params
        )
      else
        Addressable::URI.new(
          host: 'api.myvr.com',
          port: 80,
          scheme: 'https',
          path: path,
          query_values: params
        )
      end
    end

    private

    def assert_class_type(klass)
      unless klass.is_a?(String) || klass.is_a?(Class)
        raise 'Class of object(s) to return must be string or class'
      end
    end
  end
end
